// Licensed to Apache Software Foundation (ASF) under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Apache Software Foundation (ASF) licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package profiling

import (
	"github.com/urfave/cli/v2"

	"github.com/apache/skywalking-cli/internal/commands/profiling/continuous"
	"github.com/apache/skywalking-cli/internal/commands/profiling/ebpf"
	"github.com/apache/skywalking-cli/internal/commands/profiling/trace"
)

var Command = &cli.Command{
	Name:  "profiling",
	Usage: "profiling related sub-command",
	UsageText: `If your application has performance issue, you could try to profiling. 
Please following sub-command to get more information.`,
	Subcommands: []*cli.Command{
		trace.Command,
		ebpf.Command,
		continuous.Command,
	},
}
